"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("../index");
const validator = new index_1.Validator();
describe("isAlphabet", () => {
    it("should return true for single alphabetic characters", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isAlphabet("a")).toBeTruthy();
        expect(yield validator.isAlphabet("Z")).toBeTruthy();
    }));
    it("should return false for non-alphabetic characters", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isAlphabet("1")).toBeFalsy();
        expect(yield validator.isAlphabet("@")).toBeFalsy();
        expect(yield validator.isAlphabet("ab")).toBeFalsy();
    }));
});
describe("isEmail", () => {
    it("should validate correct email addresses", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isEmail("test@example.com")).toBeTruthy();
        expect(yield validator.isEmail("user.name+tag@example.co.uk")).toBeTruthy();
    }));
    it("should reject invalid email addresses", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isEmail("invalid.email")).toBeFalsy();
        expect(yield validator.isEmail("@example.com")).toBeFalsy();
        expect(yield validator.isEmail("test@")).toBeFalsy();
    }));
});
describe("isValidPassword", () => {
    it("should validate correct password", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidPassword("P@ssw0rd")).toBeTruthy();
        expect(yield validator.isValidPassword("NewUser$$**40")).toBeTruthy();
    }));
    it("should reject invalid password", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidPassword("pass")).toBeFalsy();
        expect(yield validator.isValidPassword("1234")).toBeFalsy();
    }));
});
describe("isValidUsername", () => {
    it("should validate correct username", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidUsername("johndoe34")).toBeTruthy();
        expect(yield validator.isValidUsername("danielidowu")).toBeTruthy();
    }));
    it("should reject invalid username", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidUsername("123e")).toBeFalsy();
        expect(yield validator.isValidUsername("*&7w")).toBeFalsy();
    }));
});
describe("isValidURL", () => {
    it("should validate correct URLs", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidURL("https://example.com")).toBeTruthy();
        expect(yield validator.isValidURL("http://sub.example.com/path")).toBeTruthy();
        expect(yield validator.isValidURL("example.com")).toBeTruthy();
    }));
    it("should reject invalid URLs", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidURL("not-a-url")).toBeFalsy();
        expect(yield validator.isValidURL("http://")).toBeFalsy();
        expect(yield validator.isValidURL("https://.com")).toBeFalsy();
    }));
});
describe("isValidTime", () => {
    it("should validate correct time formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidTime("00:00")).toBeTruthy();
        expect(yield validator.isValidTime("01:23")).toBeTruthy();
        expect(yield validator.isValidTime("12:34")).toBeTruthy();
        expect(yield validator.isValidTime("23:59")).toBeTruthy();
    }));
    it("should not validate incorrect time formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidTime("24:00")).toBeFalsy();
        expect(yield validator.isValidTime("00:60")).toBeFalsy();
        expect(yield validator.isValidTime("abc")).toBeFalsy();
    }));
});
describe("isValidIP", () => {
    it("should validate correct IPv4 addresses", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidIP("192.168.1.1")).toBeTruthy();
        expect(yield validator.isValidIP("10.0.0.1")).toBeTruthy();
        expect(yield validator.isValidIP("255.255.255.255")).toBeTruthy();
    }));
    it("should not validate incorrect IPv4 addresses", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidIP("192.168.1")).toBeFalsy();
        expect(yield validator.isValidIP("192.168.1.1.1")).toBeFalsy();
        expect(yield validator.isValidIP("256.0.0.0")).toBeFalsy();
        expect(yield validator.isValidIP("abc")).toBeFalsy();
    }));
});
describe("isValidCreditCard", () => {
    it("should validate correct credit card numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidCreditCard("4111111111111111")).toBeTruthy();
        // expect(
        //   await validator.isValidCreditCard("4111-1111-1111-1111")
        // ).toBeTruthy();
        expect(yield validator.isValidCreditCard("5555555555554444")).toBeTruthy();
        expect(yield validator.isValidCreditCard("5105105105105100")).toBeTruthy();
    }));
    it("should not validate incorrect credit card numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidCreditCard("4111111111111")).toBeFalsy();
        expect(yield validator.isValidCreditCard("4111111111111112")).toBeFalsy();
        expect(yield validator.isValidCreditCard("5555555555554443")).toBeFalsy();
        expect(yield validator.isValidCreditCard("abc")).toBeFalsy();
    }));
});
describe("isValidIPv6", () => {
    it("should validate correct IPv6 addresses", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidIPv6("2001:0db8:85a3:0000:0000:8a2e:0370:7334")).toBeTruthy();
        expect(yield validator.isValidIPv6("2001:db8:85a3::8a2e:370:7334")).toBeTruthy();
        expect(yield validator.isValidIPv6("fe80::1")).toBeTruthy();
    }));
    it("should not validate incorrect IPv6 addresses", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidIPv6("2001:0db8:85a3:0000:0000:8a2e:0370:7334:1")).toBeFalsy();
        expect(yield validator.isValidIPv6("2001:0db8:85a3:0000:0000:8a2e:0370")).toBeFalsy();
        expect(yield validator.isValidIPv6("2001:0db8:85a3:0000:0000:8a2e:0370:7334:")).toBeFalsy();
        expect(yield validator.isValidIPv6("abc")).toBeFalsy();
    }));
});
describe("extractYouTubeVideoId", () => {
    it("should extract valid YouTube video IDs", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.extractYouTubeVideoId("https://www.youtube.com/watch?v=dQw4w9WgXcQ")).toBe("dQw4w9WgXcQ");
        expect(yield validator.extractYouTubeVideoId("https://youtu.be/dQw4w9WgXcQ")).toBe("dQw4w9WgXcQ");
        expect(yield validator.extractYouTubeVideoId("https://www.youtube.com/embed/dQw4w9WgXcQ")).toBe("dQw4w9WgXcQ");
        expect(yield validator.extractYouTubeVideoId("https://www.youtube.com/v/dQw4w9WgXcQ")).toBe("dQw4w9WgXcQ");
    }));
    it("should not extract invalid YouTube video IDs", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.extractYouTubeVideoId("https://www.youtube.com/watch?v=")).toBe(null);
        expect(yield validator.extractYouTubeVideoId("https://youtu.be/")).toBe(null);
        expect(yield validator.extractYouTubeVideoId("https://www.youtube.com/embed/")).toBe(null);
        expect(yield validator.extractYouTubeVideoId("https://www.youtube.com/v/")).toBe(null);
        expect(yield validator.extractYouTubeVideoId("abc")).toBe(null);
    }));
});
describe("isValidDateYYYYMMDD", () => {
    it("should validate correct YYYY-MM-DD dates", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDateYYYYMMDD("2023-04-15")).toBeTruthy();
        expect(yield validator.isValidDateYYYYMMDD("2024-02-29")).toBeTruthy();
        expect(yield validator.isValidDateYYYYMMDD("2023-12-31")).toBeTruthy();
    }));
    it("should not validate incorrect YYYY-MM-DD dates", () => __awaiter(void 0, void 0, void 0, function* () {
        // expect(await validator.isValidDateYYYYMMDD("2023-02-30")).toBeFalsy();
        expect(yield validator.isValidDateYYYYMMDD("2023-13-01")).toBeFalsy();
        expect(yield validator.isValidDateYYYYMMDD("23-04-15")).toBeFalsy();
        expect(yield validator.isValidDateYYYYMMDD("2023-4-1")).toBeFalsy();
    }));
});
describe("date_DDMMYYYY_Regex", () => {
    it("should validate correct DD-MM-YYYY dates", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDateDDMMYYYY("15-04-2023")).toBeTruthy();
        expect(yield validator.isValidDateDDMMYYYY("29-02-2024")).toBeTruthy();
        expect(yield validator.isValidDateDDMMYYYY("31-12-2023")).toBeTruthy();
    }));
    it("should not validate incorrect DD-MM-YYYY dates", () => __awaiter(void 0, void 0, void 0, function* () {
        // expect(await validator.isValidDateDDMMYYYY("30-02-2023")).toBeFalsy();
        expect(yield validator.isValidDateDDMMYYYY("01-13-2023")).toBeFalsy();
        expect(yield validator.isValidDateDDMMYYYY("4-1-23")).toBeFalsy();
        // expect(await validator.isValidDateDDMMYYYY("15/04/2023")).toBeFalsy();
    }));
});
describe("isValidTime24H", () => {
    it("should validate correct 24-hour time formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidTime24H("00:00")).toBeTruthy();
        expect(yield validator.isValidTime24H("12:34")).toBeTruthy();
        expect(yield validator.isValidTime24H("23:59")).toBeTruthy();
    }));
    it("should not validate incorrect 24-hour time formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidTime24H("24:00")).toBeFalsy();
        expect(yield validator.isValidTime24H("00:60")).toBeFalsy();
        expect(yield validator.isValidTime24H("abc")).toBeFalsy();
    }));
});
describe("isValidTime12H", () => {
    it("should validate correct 12-hour time formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidTime12H("1:23 PM")).toBeTruthy();
        expect(yield validator.isValidTime12H("12:00 AM")).toBeTruthy();
        expect(yield validator.isValidTime12H("11:59 PM")).toBeTruthy();
    }));
    it("should not validate incorrect 12-hour time formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidTime12H("24:00 PM")).toBeFalsy();
        expect(yield validator.isValidTime12H("00:60 AM")).toBeFalsy();
        expect(yield validator.isValidTime12H("13:00 PM")).toBeFalsy();
        expect(yield validator.isValidTime12H("abc")).toBeFalsy();
    }));
});
describe("isValidDateTimeISO8601", () => {
    it("should validate correct ISO 8601 date-time formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDateTimeISO8601("2023-04-15T12:34:56Z")).toBeTruthy();
        expect(yield validator.isValidDateTimeISO8601("2023-04-15T12:34:56.123Z")).toBeTruthy();
        expect(yield validator.isValidDateTimeISO8601("2023-04-15T12:34:56+02:00")).toBeTruthy();
        expect(yield validator.isValidDateTimeISO8601("2023-04-15T12:34:56.123+02:00")).toBeTruthy();
    }));
    it("should not validate incorrect ISO 8601 date-time formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDateTimeISO8601("2023-04-15 12:34:56Z")).toBeFalsy();
        expect(yield validator.isValidDateTimeISO8601("2023-04-15T12:34Z")).toBeFalsy();
        expect(yield validator.isValidDateTimeISO8601("2023-04-15T12:34:56.")).toBeFalsy();
        expect(yield validator.isValidDateTimeISO8601("2023-04-15T12:34:56+2:00")).toBeFalsy();
        expect(yield validator.isValidDateTimeISO8601("abc")).toBeFalsy();
    }));
});
describe("isValidPhone", () => {
    it("should validate correct phone numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidPhone("+1-555-555-5555")).toBeTruthy();
        expect(yield validator.isValidPhone("(555) 555-5555")).toBeTruthy();
        expect(yield validator.isValidPhone("555.555.5555")).toBeTruthy();
    }));
    it("should reject invalid phone numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidPhone("abc-def-ghij")).toBeFalsy();
        expect(yield validator.isValidPhone("+1+")).toBeFalsy();
    }));
});
describe("isValidDate", () => {
    it("should validate correct dates", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDate("2024-02-29")).toBeTruthy(); // Leap year
        expect(yield validator.isValidDate("2023-12-31")).toBeTruthy();
        expect(yield validator.isValidDate("2024-01-01")).toBeTruthy();
    }));
    it("should reject invalid dates", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDate("2024-13-01")).toBeFalsy();
        expect(yield validator.isValidDate("2024-04-31")).toBeFalsy();
    }));
});
describe("isValidHexColor", () => {
    it("should validate correct hex colors", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidHexColor("#ffffff")).toBeTruthy();
        expect(yield validator.isValidHexColor("#fff")).toBeTruthy();
        expect(yield validator.isValidHexColor("123abc")).toBeTruthy();
    }));
    it("should reject invalid hex colors", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidHexColor("#ffg")).toBeFalsy();
        expect(yield validator.isValidHexColor("#ff")).toBeFalsy();
        expect(yield validator.isValidHexColor("#fffffff")).toBeFalsy();
    }));
});
describe("isValidZipCode", () => {
    it("should validate correct ZIP codes", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidZipCode("12345")).toBeTruthy();
        expect(yield validator.isValidZipCode("12345-6789")).toBeTruthy();
    }));
    it("should reject invalid ZIP codes", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidZipCode("1234")).toBeFalsy();
        expect(yield validator.isValidZipCode("123456")).toBeFalsy();
        expect(yield validator.isValidZipCode("12345-")).toBeFalsy();
    }));
});
describe("isValidSSN", () => {
    it("should validate correct SSNs", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidSSN("123-45-6789")).toBeTruthy();
        expect(yield validator.isValidSSN("234-56-7890")).toBeTruthy();
    }));
    it("should reject invalid SSNs", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidSSN("666-45-6789")).toBeFalsy();
        expect(yield validator.isValidSSN("000-45-6789")).toBeFalsy();
        expect(yield validator.isValidSSN("123-00-6789")).toBeFalsy();
    }));
});
describe("isValidWindowsPath", () => {
    it("should validate correct Windows paths", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidWindowsPath("C:\\Program Files\\App")).toBeTruthy();
        expect(yield validator.isValidWindowsPath("D:\\Documents\\file")).toBeTruthy();
    }));
    it("should reject invalid Windows paths", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidWindowsPath("C:")).toBeFalsy();
        expect(yield validator.isValidWindowsPath("/usr/local")).toBeFalsy();
        expect(yield validator.isValidWindowsPath("C:\\Program Files?")).toBeFalsy();
    }));
});
describe("isValidUnixPath", () => {
    it("should validate correct Unix paths", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidUnixPath("/usr/local/bin")).toBeTruthy();
        expect(yield validator.isValidUnixPath("/home/user")).toBeTruthy();
    }));
    it("should reject invalid Unix paths", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidUnixPath("usr/local")).toBeFalsy();
        expect(yield validator.isValidUnixPath("C:\\Windows")).toBeFalsy();
    }));
});
describe("isValidSlug", () => {
    it("should validate correct slugs", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidSlug("my-blog-post")).toBeTruthy();
        expect(yield validator.isValidSlug("article-123")).toBeTruthy();
    }));
    it("should reject invalid slugs", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidSlug("My Blog Post")).toBeFalsy();
        expect(yield validator.isValidSlug("article_123")).toBeFalsy();
        expect(yield validator.isValidSlug("-invalid-slug-")).toBeFalsy();
    }));
});
describe("containsHTMLTag", () => {
    it("should detect HTML tags", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.containsHTMLTag("<p>text</p>")).toBeTruthy();
        expect(yield validator.containsHTMLTag("<br/>")).toBeTruthy();
    }));
    it("should handle text without HTML tags", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.containsHTMLTag("plain text")).toBeFalsy();
        expect(yield validator.containsHTMLTag("text > text")).toBeFalsy();
    }));
});
describe("containsOnlyLettersAndSpaces", () => {
    it("should validate text with only letters and spaces", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.containsOnlyLettersAndSpaces("Hello World")).toBeTruthy();
        expect(yield validator.containsOnlyLettersAndSpaces("OnlyLetters")).toBeTruthy();
    }));
    it("should reject text with other characters", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.containsOnlyLettersAndSpaces("Hello123")).toBeFalsy();
        expect(yield validator.containsOnlyLettersAndSpaces("Hello!")).toBeFalsy();
    }));
});
describe("containsOnlyNumbers", () => {
    it("should validate strings with only numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.containsOnlyNumbers("123")).toBeTruthy();
        expect(yield validator.containsOnlyNumbers("0")).toBeTruthy();
    }));
    it("should reject strings with non-numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.containsOnlyNumbers("123a")).toBeFalsy();
        expect(yield validator.containsOnlyNumbers("12.3")).toBeFalsy();
    }));
});
describe("isValidFileExtension", () => {
    it("should validate allowed file extensions", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidFileExtension("image.jpg")).toBeTruthy();
        expect(yield validator.isValidFileExtension("document.pdf")).toBeTruthy();
    }));
    it("should reject invalid file extensions", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidFileExtension("script.js")).toBeFalsy();
        expect(yield validator.isValidFileExtension("image")).toBeFalsy();
    }));
});
describe("isValidDecimal", () => {
    it("should validate decimal numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDecimal("123.45")).toBeTruthy();
        expect(yield validator.isValidDecimal("0.5")).toBeTruthy();
    }));
    it("should reject non-decimal numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDecimal("123")).toBeFalsy();
        expect(yield validator.isValidDecimal("-123.45")).toBeFalsy();
    }));
});
describe("isValidNegativeDecimal", () => {
    it("should validate negative decimal numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidNegativeDecimal("-123.45")).toBeTruthy();
        expect(yield validator.isValidNegativeDecimal("-0.5")).toBeTruthy();
    }));
    it("should reject positive decimal numbers", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidNegativeDecimal("123.45")).toBeFalsy();
        expect(yield validator.isValidNegativeDecimal("0.5")).toBeFalsy();
    }));
});
describe("isValidCurrencyUSD", () => {
    it("should validate USD currency format", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidCurrencyUSD("$123.45")).toBeTruthy();
        expect(yield validator.isValidCurrencyUSD("$1,234.56")).toBeTruthy();
    }));
    it("should reject invalid USD formats", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidCurrencyUSD("123.45")).toBeFalsy();
        expect(yield validator.isValidCurrencyUSD("$123.456")).toBeFalsy();
    }));
});
describe("isValidPercentage", () => {
    it("should validate percentage values", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidPercentage("100%")).toBeTruthy();
        expect(yield validator.isValidPercentage("50.5%")).toBeTruthy();
    }));
    it("should reject invalid percentage values", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidPercentage("101%")).toBeFalsy();
        expect(yield validator.isValidPercentage("-1%")).toBeFalsy();
    }));
});
describe("isValidDomain", () => {
    it("should validate domain names", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDomain("example.com")).toBeTruthy();
        expect(yield validator.isValidDomain("sub.example.com")).toBeTruthy();
    }));
    it("should reject invalid domain names", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidDomain("example")).toBeFalsy();
        expect(yield validator.isValidDomain("-example.com")).toBeFalsy();
    }));
});
describe("isValidMacAddress", () => {
    it("should validate MAC addresses", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidMacAddress("00:1A:2B:3C:4D:5E")).toBeTruthy();
        expect(yield validator.isValidMacAddress("00-1A-2B-3C-4D-5E")).toBeTruthy();
    }));
    it("should reject invalid MAC addresses", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidMacAddress("00:1A:2B:3C:4D")).toBeFalsy();
        expect(yield validator.isValidMacAddress("00:1A:2B:3C:4D:5G")).toBeFalsy();
    }));
});
describe("isValidLatitude", () => {
    it("should validate latitude values", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidLatitude("45.0")).toBeTruthy();
        expect(yield validator.isValidLatitude("-90.0")).toBeTruthy();
    }));
    it("should reject invalid latitude values", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidLatitude("91.0")).toBeFalsy();
        expect(yield validator.isValidLatitude("-91.0")).toBeFalsy();
    }));
});
describe("isValidLongitude", () => {
    it("should validate longitude values", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidLongitude("180.0")).toBeTruthy();
        expect(yield validator.isValidLongitude("-180.0")).toBeTruthy();
    }));
    it("should reject invalid longitude values", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.isValidLongitude("181.0")).toBeFalsy();
        expect(yield validator.isValidLongitude("-181.0")).toBeFalsy();
    }));
});
describe("noSpecialCharacter", () => {
    it("should validate strings without special characters", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.noSpecialCharacter("Hello123")).toBeTruthy();
        expect(yield validator.noSpecialCharacter("Just Text")).toBeTruthy();
    }));
    it("should reject strings with special characters", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.noSpecialCharacter("Hello!")).toBeFalsy();
        expect(yield validator.noSpecialCharacter("Text@123")).toBeFalsy();
    }));
});
describe("noConsecutiveSpaces", () => {
    it("should validate strings without consecutive spaces", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.noConsecutiveSpaces("Hello World")).toBeTruthy();
        expect(yield validator.noConsecutiveSpaces("Just Text")).toBeTruthy();
    }));
    it("should reject strings with consecutive spaces", () => __awaiter(void 0, void 0, void 0, function* () {
        expect(yield validator.noConsecutiveSpaces("Hello  World")).toBeFalsy();
        expect(yield validator.noConsecutiveSpaces("Text   Here")).toBeFalsy();
    }));
});
