"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Validator = void 0;
class Validator {
    constructor() {
        // Regular expressions
        this.alphabetRegex = /^[a-zA-Z]$/;
        this.emailRegex = /^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$/;
        this.passwordRegex = /^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?=.*[@$!%*?&^#()])[A-Za-z\d@$!%*?&^#()]{8,}$/;
        this.usernameRegex = /^[a-zA-Z_][a-zA-Z0-9_]{2,15}$/;
        this.urlRegex = /^(https?:\/\/)?([a-z0-9-]+\.)+[a-z]{2,}(\/[^\s]*)?$/;
        this.phoneRegex = /^\+?(?:\d{1,3})?[-.\s]?(\(?\d{1,4}\)?)?[-.\s]?(\d{1,4})[-.\s]?(\d{1,4})[-.\s]?(\d{1,4})$/;
        this.dateRegex = /^(?:(?!0000)\d{4})-(?:(?:0[1-9]|1[0-2])-(?:0[1-9]|1\d|2[0-8])|(?:0[13-9]|1[0-2])-(?:29|30)|(?:0[13578]|1[02])-31|02-29)$/;
        this.timeRegex = /^([01]?[0-9]|2[0-3]):[0-5][0-9]$/;
        this.ipRegex = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
        this.hexColorRegex = /^#?([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$/;
        this.creditCardRegex = /^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|6(?:011|5[0-9]{2})[0-9]{12}|(?:2131|1800|35\d{3})\d{11})[- ]?(\d{4})?$/;
        this.zipCodeRegex = /^\d{5}(-\d{4})?$/;
        this.ssnRegex = /^(?!000|666)[0-8][0-9]{2}-(?!00)[0-9]{2}-(?!0000)[0-9]{4}$/;
        this.ipv6Regex = /^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))$/;
        this.windowsPathRegex = /^[a-zA-Z]:\\(?:[^\\/:*?"<>|\r\n]+\\)*[^\\/:*?"<>|\r\n]*$/;
        this.unixPathRegex = /^\/(?:[^/\0]+\/)*[^/\0]*$/;
        this.slugRegex = /^[a-z0-9]+(?:-[a-z0-9]+)*$/;
        this.htmlTagRegex = /<([a-z]+)(\s[^>]*)?>.*?<\/\1>|<([a-z]+)(\s[^>]*)?\/?>/i;
        this.lettersAndSpacesRegex = /^[A-Za-z\s]*$/;
        this.numbersOnlyRegex = /^\d+$/;
        this.fileExtensionRegex = /^[^/]+?\.(jpg|jpeg|png|gif|pdf)$/;
        this.youtubeVideoIdRegex = /(?:https?:\/\/)?(?:www\.)?(?:youtu\.be\/|(?:[a-z]{2,3}\.)?youtube\.com\/(?:watch\?v=|embed\/|v\/|.+\?v=|.+\/|.*[?&]v=))([\w-]{11})/;
        this.decimalRegex = /^\d+\.\d+$/;
        this.negativeDecimalRegex = /^-\d+\.\d+$/;
        this.currencyUSDRegex = /^\$\d{1,3}(,\d{3})*(\.\d{2})?$/;
        this.percentageRegex = /^(100(\.00?)?|[1-9]?\d(\.\d{1,2})?)%?$/;
        this.date_YYYYMMDD_Regex = /^\d{4}-(0[1-9]|1[0-2])-(0[1-9]|[12]\d|3[01])$/;
        this.date_DDMMYYYY_Regex = /^(0[1-9]|[12]\d|3[01])[- /.](0[1-9]|1[0-2])[- /.]\d{4}$/;
        this.time24HRegex = /^([01]?[0-9]|2[0-3]):[0-5][0-9]$/;
        this.time12HRegex = /^(0?[1-9]|1[0-2]):[0-5][0-9] ?[AaPp][Mm]$/;
        this.dateTime_ISO8601_Regex = /^\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d(\.\d+)?(([+-]\d\d:\d\d)|Z)?$/;
        this.domainRegex = /^(?!-)[a-zA-Z0-9-]+(\.[a-zA-Z0-9-]+)*\.[a-zA-Z]{2,}(?<!-)$/;
        this.macAddressRegex = /^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/;
        this.latitudeRegex = /^-?(90(\.0+)?|[1-8]?\d(\.\d+)?)$/;
        this.longitudeRegex = /^-?(180(\.0+)?|1[0-7]\d(\.\d+)?|[1-9]?\d(\.\d+)?)$/;
        this.noSpecialCharRegex = /^[A-Za-z0-9\s]*$/;
        this.noConsecutiveSpacesRegex = /^(?!.*\s{2})[A-Za-z0-9\s]*$/;
    }
    isAlphabet(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.alphabetRegex.test(value);
        });
    } //
    isEmail(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.emailRegex.test(value);
        });
    } //
    isValidPassword(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.passwordRegex.test(value);
        });
    } //
    isValidUsername(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.usernameRegex.test(value);
        });
    } //
    isValidURL(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.urlRegex.test(value);
        });
    } //
    isValidPhone(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.phoneRegex.test(value);
        });
    } //
    isValidDate(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.dateRegex.test(value);
        });
    } //
    isValidTime(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.timeRegex.test(value);
        });
    } // **
    isValidIP(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.ipRegex.test(value);
        });
    } // **
    isValidHexColor(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.hexColorRegex.test(value);
        });
    } //
    isValidCreditCard(value) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.creditCardRegex.test(value)) {
                return false;
            }
            // Luhn algorithm implementation
            const sanitizedNumber = value.replace(/\D/g, "");
            if (sanitizedNumber.length < 2) {
                return false;
            }
            let sum = 0;
            let shouldDouble = false;
            // Process digits from right to left
            for (let i = sanitizedNumber.length - 1; i >= 0; i--) {
                let digit = parseInt(sanitizedNumber.charAt(i), 10);
                if (shouldDouble) {
                    digit *= 2;
                    if (digit > 9) {
                        digit -= 9;
                    }
                }
                sum += digit;
                shouldDouble = !shouldDouble;
            }
            return sum % 10 === 0;
        });
    } // **
    isValidZipCode(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.zipCodeRegex.test(value);
        });
    } //
    isValidSSN(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.ssnRegex.test(value);
        });
    } //
    isValidIPv6(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.ipv6Regex.test(value);
        });
    } // **
    isValidWindowsPath(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.windowsPathRegex.test(value);
        });
    } //
    isValidUnixPath(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.unixPathRegex.test(value);
        });
    } //
    isValidSlug(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.slugRegex.test(value);
        });
    } //
    containsHTMLTag(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.htmlTagRegex.test(value);
        });
    } //
    containsOnlyLettersAndSpaces(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.lettersAndSpacesRegex.test(value);
        });
    } //
    containsOnlyNumbers(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.numbersOnlyRegex.test(value);
        });
    } //
    isValidFileExtension(filename) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.fileExtensionRegex.test(filename);
        });
    } //
    extractYouTubeVideoId(url) {
        return __awaiter(this, void 0, void 0, function* () {
            const match = url.match(this.youtubeVideoIdRegex);
            return match ? match[1] : null;
        });
    } //
    isValidDecimal(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.decimalRegex.test(value);
        });
    } //
    isValidNegativeDecimal(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.negativeDecimalRegex.test(value);
        });
    } //
    isValidCurrencyUSD(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.currencyUSDRegex.test(value);
        });
    } //
    isValidPercentage(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.percentageRegex.test(value);
        });
    } //
    isValidDateYYYYMMDD(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.date_YYYYMMDD_Regex.test(value);
        });
    }
    isValidDateDDMMYYYY(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.date_DDMMYYYY_Regex.test(value);
        });
    }
    isValidTime24H(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.time24HRegex.test(value);
        });
    }
    isValidTime12H(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.time12HRegex.test(value);
        });
    }
    isValidDateTimeISO8601(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.dateTime_ISO8601_Regex.test(value);
        });
    }
    isValidDomain(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.domainRegex.test(value);
        });
    } //
    isValidMacAddress(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.macAddressRegex.test(value);
        });
    } //
    isValidLatitude(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.latitudeRegex.test(value);
        });
    } //
    isValidLongitude(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.longitudeRegex.test(value);
        });
    } //
    noSpecialCharacter(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.noSpecialCharRegex.test(value);
        });
    } //
    noConsecutiveSpaces(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.noConsecutiveSpacesRegex.test(value);
        });
    } //
}
exports.Validator = Validator;
